class Admin::PortalTemplateController < OrbitMemberController
  layout "member_plugin"
  include Admin::PortalTemplateHelper

  before_action :set_offer, only: [:show, :edit , :update]
  before_action :find_offer, only: [:destroy]
  before_action :set_plugin
  # before_action :get_settings,:only => [:new, :edit, :setting]

  before_action :need_access_right
  before_action :allow_admin_only, :only => [:index, :setting]

  def index
    @offers = Offer.page(params[:page]).per(10)
  end

  def new
    @member = MemberProfile.find_by(:uid=>params['uid'].to_s) rescue nil
    @offer = Offer.new
    if params[:desktop]
      render :layout => false
    end
  end

  def role_setting
    ma = ModuleApp.find_by_key('portal_template')
    @authorizations = ma.authorizations.where(:role_id.ne => nil)
    @portal_setting = PortalSetting.first
    if @portal_setting.nil?
      @portal_setting = PortalSetting.new
    end
    @role_type = params[:role_type]
    render :layout => false
  end


  def create
    if !offer_params['member_profile_id'].blank?

      @member = MemberProfile.find(offer_params['member_profile_id']) rescue nil
      @offer = Offer.new(offer_params)
      @offer.save

      if params[:desktop] == "true"
        render json: {"data" => get_offer_list}.to_json
      else
        redirect_to params['referer_url']
      end
    else
      offer_params['member_profile_id'] = User.find(current_user.id).member_profile_id

      @offer = Offer.new(offer_params)
      @offer.save

      if params[:desktop] == "true"
        render json: {"data" => get_offer_list}.to_json
      end

      redirect_to params['referer_url']
    end
  end

  def edit
    @member = @offer.member_profile rescue nil
    if params[:desktop]
      render :layout => false
    end
  end

  def update
    @member = @experience.member_profile rescue nil
    @experience.update_attributes(experience_params)
    @experience.save
    if params[:desktop] == "true"
      render json: {"data" => get_paper_list}.to_json
    else
      redirect_to params['referer_url']
    end
  end

  def destroy
    @offer.destroy
    respond_to do |format|
      format.html { redirect_to(admin_portal_template_index_url) }
      # format.xml { head :ok }
      format.js
      format.json {render json: {"success" => true}}
    end
  end

  def toggle_hide
    if params[:ids]
      @offers = Offer.any_in(_id: params[:ids])

      @offers.each do |offer|
        offer.is_hidden = params[:disable]
        offer.save
      end
    end

    render json: {"success"=>true}
  end

  def setting
  end

  def update_setting
    @portal_setting = PortalSetting.first
    if @portal_setting.nil?
      @portal_setting = PortalSetting.new
    end
    @portal_setting.update_attributes(portal_setting_params)
    @role_type = params[:role_type]
    render :layout => false
  end

  def portal_setting_delete
    ps = PortalSetting.first
    if params[:role_type] == "offerer"
      ps.offerer_role = nil
    elsif params[:role_type] == "applicant"
      ps.applicant_role = nil
    end
    ps.save
    render :json => {
      "success" => true
    }
  end

  def set_plugin
    @plugin = OrbitApp::Plugin::Registration.all.select{|plugin| plugin.app_name.eql? 'Portal'}.first
  end

  def offer_application_delete
    application = OfferApplication.find(params[:id])
    application.destroy
    respond_to do |format|
      format.html { redirect_to(admin_portal_template_index_url) }
      # format.xml { head :ok }
      format.js
      format.json {render json: {"success" => true}}
    end
  end

  private

  def set_offer
    path = request.path.split('/')
    if path.last.include? '-'
      uid = path[-1].split("-").last
      uid = uid.split("?").first
    else
      uid = path[-2].split("-").last
      uid = uid.split("?").first
    end
     @offer = Offer.find_by(:uid => uid) rescue Offer.find(params[:id])
  end

  def find_offer
    @offer = Offer.find_by(id: params[:id].to_s)
  end

  def offer_params
    params.require(:offer).permit! rescue nil
  end

  def portal_setting_params
    params.require(:portal_setting).permit! rescue nil
  end

end
