class Offer
  include Mongoid::Document
  include Mongoid::Timestamps
  include OrbitModel::Status
  include Slug

  field :offer_title, localize: true

  belongs_to :member_profile

  field :create_user_id, :type => BSON::ObjectId
  field :update_user_id, :type => BSON::ObjectId

  # paginates_per 10



  index({start_date: -1, :end_date => -1, _id: -1}, { unique: false, background: false })
  scope :sort_date, ->{ order_by(:start_date => "desc", :end_date => "desc", :id => "desc") }
  scope :sort_for_frontend, ->{ where(:is_hidden=>false).order_by(:start_date => "desc", :end_date => "desc", :id => "desc")}



  def slug_title
    [self.offer_title].join(' ')
  end

  def self.get_plugin_datas_to_member(datas)

    fields_to_show = [
      "offer_title"
    ]

    fields_to_remove = []

    pd_title = []

    fields_to_show.each do |t|
      if (self.fields[t].type.to_s == "String" || self.fields[t].type.to_s == "Object" rescue false)
        fields_to_remove << t if (datas.where(t.to_sym.ne => nil).or(t.to_sym.ne => "").count == 0 rescue false)
      elsif t == "duration"
        fields_to_remove << t if (datas.where(:start_date.ne => nil).count == 0 rescue false)
      else
        fields_to_remove << t if (datas.where(t.to_sym.ne => nil).count == 0 rescue false)
      end
      pd_title <<  {
          "plugin_data_title" => I18n.t("portal_template.#{t}")
        } if !fields_to_remove.include?(t)
    end

    fields_to_show = fields_to_show - fields_to_remove

    plugin_datas = datas.sort_for_frontend.collect.with_index do |p,idx|

      pd_data = []
      fields_to_show.collect do |t|
        if t == "offer_title"
          link = OrbitHelper.url_to_plugin_show(p.to_param,'portal_template')
          url_to_plugin_show_blank = OrbitHelper.instance_variable_get(:@url_to_plugin_show_blank)
          tmp_title = p.organizationt_title
          pd_data << { "data_title" => (url_to_plugin_show_blank ? tmp_title : "<a title=\"#{tmp_title}\" href=\"#{link}\" target=\"_blank\">#{tmp_title}</a>") }
        end
      end

      {
        "portal_template"=>"",
        "pd_datas" => pd_data,
        "sort-index" => idx
      }

    end
    plugin_datas = plugin_datas.sort_by{|pd| [pd["type-sort"], pd["sort-index"]]}
    return [pd_title,plugin_datas]

  end

  def get_plugin_data(fields_to_show)
    plugin_datas = []
    fields_to_show.each do |field|
      plugin_data = self.get_plugin_field_data(field) rescue nil
      next if plugin_data.blank? or plugin_data['value'].blank?
      plugin_datas << plugin_data
    end
    plugin_datas
  end

  def get_plugin_field_data(field)
    case field
    when "language"
      value = I18n.t(self.language) rescue ""
    else
      value = self.send(field) rescue ""
    end

    value = (value =~ /\A#{URI::regexp(['http', 'https'])}\z/) ? "<a href=\"#{value}\" target='blank'>#{value}</a>" : value

    {
      "key"=>field,
      "title"=>I18n.t('portal_template.'+field),
      "value"=>value
    }
  end

end
